==> openshift-model-config-6.8.1-sources.jar: io/fabric8/openshift/api/model/config/v1/DNSZoneFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DNSZoneFluent<A extends DNSZoneFluent<A>> extends BaseFluent<A>{
  public DNSZoneFluent() {
  }
  public DNSZoneFluent(DNSZone instance) {
    instance = (instance != null ? instance : new DNSZone());

    if (instance != null) {
      this.withId(instance.getId());
      this.withTags(instance.getTags());
      this.withId(instance.getId());
      this.withTags(instance.getTags());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String id;
  private Map<String,String> tags;
  private Map<String,Object> additionalProperties;
  public String getId() {
    return this.id;
  }
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  public boolean hasId() {
    return this.id != null;
  }
  public A addToTags(String key,String value) {
    if(this.tags == null && key != null && value != null) { this.tags = new LinkedHashMap(); }
    if(key != null && value != null) {this.tags.put(key, value);} return (A)this;
  }
  public A addToTags(Map<String,String> map) {
    if(this.tags == null && map != null) { this.tags = new LinkedHashMap(); }
    if(map != null) { this.tags.putAll(map);} return (A)this;
  }
  public A removeFromTags(String key) {
    if(this.tags == null) { return (A) this; }
    if(key != null && this.tags != null) {this.tags.remove(key);} return (A)this;
  }
  public A removeFromTags(Map<String,String> map) {
    if(this.tags == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.tags != null){this.tags.remove(key);}}} return (A)this;
  }
  public Map<String,String> getTags() {
    return this.tags;
  }
  public <K,V>A withTags(Map<String,String> tags) {
    if (tags == null) { this.tags =  null;} else {this.tags = new LinkedHashMap(tags);} return (A) this;
  }
  public boolean hasTags() {
    return this.tags != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSZoneFluent that = (DNSZoneFluent) o;
    if (!java.util.Objects.equals(id, that.id)) return false;

    if (!java.util.Objects.equals(tags, that.tags)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(id,  tags,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (tags != null && !tags.isEmpty()) { sb.append("tags:"); sb.append(tags + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-config-6.9.0-sources.jar: io/fabric8/openshift/api/model/config/v1/DNSZoneFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DNSZoneFluent<A extends DNSZoneFluent<A>> extends BaseFluent<A>{
  public DNSZoneFluent() {
  }
  
  public DNSZoneFluent(DNSZone instance) {
    this.copyInstance(instance);
  }
  private String id;
  private Map<String,String> tags;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(DNSZone instance) {
    instance = (instance != null ? instance : new DNSZone());
  
    if (instance != null) {
        this.withId(instance.getId());
        this.withTags(instance.getTags());
        this.withId(instance.getId());
        this.withTags(instance.getTags());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getId() {
    return this.id;
  }
  
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  
  public boolean hasId() {
    return this.id != null;
  }
  
  public A addToTags(String key,String value) {
    if(this.tags == null && key != null && value != null) { this.tags = new LinkedHashMap(); }
    if(key != null && value != null) {this.tags.put(key, value);} return (A)this;
  }
  
  public A addToTags(Map<String,String> map) {
    if(this.tags == null && map != null) { this.tags = new LinkedHashMap(); }
    if(map != null) { this.tags.putAll(map);} return (A)this;
  }
  
  public A removeFromTags(String key) {
    if(this.tags == null) { return (A) this; }
    if(key != null && this.tags != null) {this.tags.remove(key);} return (A)this;
  }
  
  public A removeFromTags(Map<String,String> map) {
    if(this.tags == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.tags != null){this.tags.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getTags() {
    return this.tags;
  }
  
  public <K,V>A withTags(Map<String,String> tags) {
    if (tags == null) { this.tags =  null;} else {this.tags = new LinkedHashMap(tags);} return (A) this;
  }
  
  public boolean hasTags() {
    return this.tags != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSZoneFluent that = (DNSZoneFluent) o;
    if (!java.util.Objects.equals(id, that.id)) return false;
  
    if (!java.util.Objects.equals(tags, that.tags)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(id,  tags,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (tags != null && !tags.isEmpty()) { sb.append("tags:"); sb.append(tags + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
